==> jc-1.4.0.tar.gz: org/xml/sax/SAXException.h <==
// public class org.xml.sax.SAXException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c045a3d7d4ce55f1 org_xml_sax_SAXException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_org_xml_sax_SAXException_H_
#define _JC_org_xml_sax_SAXException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_xml_sax_SAXException$sub_refs	_jc_org_xml_sax_SAXException$sub_refs;
typedef struct _jc_org_xml_sax_SAXException$sub_nonrefs	_jc_org_xml_sax_SAXException$sub_nonrefs;
typedef struct _jc_org_xml_sax_SAXException$refs	_jc_org_xml_sax_SAXException$refs;
typedef struct _jc_org_xml_sax_SAXException$nonrefs	_jc_org_xml_sax_SAXException$nonrefs;
typedef struct _jc_org_xml_sax_SAXException$object	_jc_org_xml_sax_SAXException$object;

typedef const struct _jc_org_xml_sax_SAXException$vmethods	_jc_org_xml_sax_SAXException$vmethods;
typedef const struct _jc_org_xml_sax_SAXException$vtable	_jc_org_xml_sax_SAXException$vtable;
typedef const struct _jc_org_xml_sax_SAXException$vtype	_jc_org_xml_sax_SAXException$vtype;

// Constructors
extern void _jc_org_xml_sax_SAXException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_xml_sax_SAXException$object *);
extern void _jc_org_xml_sax_SAXException$method$_init$34e2c2e16bd56612(_jc_env *, struct _jc_org_xml_sax_SAXException$object *, struct _jc_java_lang_Exception$object *);
extern void _jc_org_xml_sax_SAXException$method$_init$c31b894660454d13(_jc_env *, struct _jc_org_xml_sax_SAXException$object *, struct _jc_java_lang_String$object *);
extern void _jc_org_xml_sax_SAXException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_org_xml_sax_SAXException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *);

// Virtual methods
extern struct _jc_java_lang_Exception$object *_jc_org_xml_sax_SAXException$method$getException$bcbfe86f697cf912(_jc_env *, struct _jc_org_xml_sax_SAXException$object *);
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_SAXException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_org_xml_sax_SAXException$object *);
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_SAXException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_org_xml_sax_SAXException$object *);

// Virtual method descriptors
extern _jc_method _jc_org_xml_sax_SAXException$method_info$getException$bcbfe86f697cf912;
extern _jc_method _jc_org_xml_sax_SAXException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_org_xml_sax_SAXException$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_org_xml_sax_SAXException$vmethods {
	struct _jc_java_lang_Exception$object	*(*getException$bcbfe86f697cf912)(_jc_env *, struct _jc_org_xml_sax_SAXException$object *);
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_org_xml_sax_SAXException$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_org_xml_sax_SAXException$object *);
};

// Vtable
struct _jc_org_xml_sax_SAXException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_org_xml_sax_SAXException$vmethods	org_xml_sax_SAXException;
};

// Vtype
struct _jc_org_xml_sax_SAXException$vtype {
	_jc_type			type;
	_jc_org_xml_sax_SAXException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_SAXException$sub_refs {
	struct _jc_java_lang_Exception$object	*exception;
};

// Reference instance fields (object)
struct _jc_org_xml_sax_SAXException$refs {
    _jc_org_xml_sax_SAXException$sub_refs	org_xml_sax_SAXException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_SAXException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_SAXException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_org_xml_sax_SAXException$sub_nonrefs	org_xml_sax_SAXException;
};

// Object instance structure
struct _jc_org_xml_sax_SAXException$object {
	_jc_org_xml_sax_SAXException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_SAXException$vtype	*vtype;
	_jc_org_xml_sax_SAXException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_SAXException$vtype _jc_org_xml_sax_SAXException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_SAXException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_SAXException$class_object;

#endif	/* _JC_org_xml_sax_SAXException_H_ */

==> jc-1.4.6.tar.gz: org/xml/sax/SAXException.h <==
// public class org.xml.sax.SAXException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class c045a3d7d4ce55f1 org_xml_sax_SAXException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_org_xml_sax_SAXException_H_
#define _JC_org_xml_sax_SAXException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Exception$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_org_xml_sax_SAXException$sub_refs	_jc_org_xml_sax_SAXException$sub_refs;
typedef struct _jc_org_xml_sax_SAXException$sub_nonrefs	_jc_org_xml_sax_SAXException$sub_nonrefs;
typedef struct _jc_org_xml_sax_SAXException$refs	_jc_org_xml_sax_SAXException$refs;
typedef struct _jc_org_xml_sax_SAXException$nonrefs	_jc_org_xml_sax_SAXException$nonrefs;
typedef struct _jc_org_xml_sax_SAXException$object	_jc_org_xml_sax_SAXException$object;

typedef const struct _jc_org_xml_sax_SAXException$vmethods	_jc_org_xml_sax_SAXException$vmethods;
typedef const struct _jc_org_xml_sax_SAXException$vtable	_jc_org_xml_sax_SAXException$vtable;
typedef const struct _jc_org_xml_sax_SAXException$vtype	_jc_org_xml_sax_SAXException$vtype;

// Constructors
extern void _jc_org_xml_sax_SAXException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_org_xml_sax_SAXException$object *) _JC_JCNI_ATTR;
extern void _jc_org_xml_sax_SAXException$method$_init$34e2c2e16bd56612(_jc_env *, struct _jc_org_xml_sax_SAXException$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;
extern void _jc_org_xml_sax_SAXException$method$_init$c31b894660454d13(_jc_env *, struct _jc_org_xml_sax_SAXException$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_org_xml_sax_SAXException$method$_init$d27a3a3f2a4ade11(_jc_env *, struct _jc_org_xml_sax_SAXException$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_Exception$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Exception$object *_jc_org_xml_sax_SAXException$method$getException$bcbfe86f697cf912(_jc_env *, struct _jc_org_xml_sax_SAXException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_SAXException$method$getMessage$13aaf240efc902b1(_jc_env *, struct _jc_org_xml_sax_SAXException$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_org_xml_sax_SAXException$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_org_xml_sax_SAXException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_org_xml_sax_SAXException$method_info$getException$bcbfe86f697cf912;
extern _jc_method _jc_org_xml_sax_SAXException$method_info$getMessage$13aaf240efc902b1;
extern _jc_method _jc_org_xml_sax_SAXException$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_org_xml_sax_SAXException$vmethods {
	struct _jc_java_lang_Exception$object	*(*getException$bcbfe86f697cf912)(_jc_env *, struct _jc_org_xml_sax_SAXException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getMessage$13aaf240efc902b1)(_jc_env *, struct _jc_org_xml_sax_SAXException$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_org_xml_sax_SAXException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_org_xml_sax_SAXException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_org_xml_sax_SAXException$vmethods	org_xml_sax_SAXException;
};

// Vtype
struct _jc_org_xml_sax_SAXException$vtype {
	_jc_type			type;
	_jc_org_xml_sax_SAXException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_org_xml_sax_SAXException$sub_refs {
	struct _jc_java_lang_Exception$object	*exception;
};

// Reference instance fields (object)
struct _jc_org_xml_sax_SAXException$refs {
    _jc_org_xml_sax_SAXException$sub_refs	org_xml_sax_SAXException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_org_xml_sax_SAXException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_org_xml_sax_SAXException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_org_xml_sax_SAXException$sub_nonrefs	org_xml_sax_SAXException;
};

// Object instance structure
struct _jc_org_xml_sax_SAXException$object {
	_jc_org_xml_sax_SAXException$refs	refs[0];
	_jc_word		lockword;
	_jc_org_xml_sax_SAXException$vtype	*vtype;
	_jc_org_xml_sax_SAXException$nonrefs	nonrefs;
};

// Type structure
extern _jc_org_xml_sax_SAXException$vtype _jc_org_xml_sax_SAXException$type;

// Array types class info structures
_JC_DECL_ARRAYS(org_xml_sax_SAXException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_org_xml_sax_SAXException$class_object;

#endif	/* _JC_org_xml_sax_SAXException_H_ */
